@@ -2,7 +2,9 @@
 
 ;; Copyright (C) 2003-2024  Free Software Foundation, Inc.
 
-;; Maintainer: Berend de Boer <berend@pobox.com>
+;; Author: Patrick Gundlach <pg@levana.de>
+;;         Berend de Boer <berend@pobox.com>
+;; Maintainer: auctex-devel@gnu.org
 ;; Keywords: tex
 
 ;; This file is part of AUCTeX.
@@ -53,9 +55,6 @@
 (require 'latex) ; for functions like `TeX-look-at' and `LaTeX-split-long-menu'
 (require 'plain-tex) ; for `plain-TeX-common-initialization'
 
-;; Silence the compiler:
-(defvar ConTeXt-extra-paragraph-commands)
-
 (defgroup ConTeXt-macro nil
   "Special support for ConTeXt macros in AUCTeX."
   :prefix "TeX-"
@@ -1121,18 +1120,59 @@ If OPTIONAL, only insert it if not empty, and then use square brackets."
 (defvar ConTeXt-item-list ()
   "List of macro's considered items.")
 
-(defun ConTeXt-paragraph-commands-regexp ()
-  "Return a regexp matching macros that should have their own line."
+(defvar ConTeXt-extra-paragraph-commands nil
+  "List of default ConTeXt macros that should begin their own line.
+Unlike `ConTeXt-paragraph-commands', each entry should be a regular
+expression without leading backslash.
+Updated in language-specific initialization.")
+
+(defcustom ConTeXt-paragraph-commands nil
+  "List of user ConTeXt macros that should begin their own line.
+The list should contain macro names without the leading backslash.
+
+If you change this variable, its value is reflected to only new buffers
+created afterwards; existing ConTeXt mode buffers aren't affected."
+  :group 'ConTeXt-macro
+  :type '(repeat (string)))
+
+(defun ConTeXt-paragraph-commands-regexp-make ()
+  "Return a regexp matching macros that should begin their own line."
   (concat
-   (regexp-quote TeX-esc) "\\("
+   (regexp-quote TeX-esc) "\\(?:"
    "[][]\\|"  ; display math delimitors (is this applicable to ConTeXt??)
    (ConTeXt-environment-start-name) "\\|"
    (ConTeXt-environment-stop-name) "\\|"
    (mapconcat #'car ConTeXt-numbered-section-list "\\b\\|") "\\b\\|"
    (mapconcat #'car ConTeXt-unnumbered-section-list "\\b\\|") "\\b\\|"
+   (mapconcat #'identity ConTeXt-paragraph-commands "\\b\\|") "\\b\\|"
    (mapconcat #'identity ConTeXt-extra-paragraph-commands "\\b\\|")
    "\\b\\|"
    (mapconcat #'identity ConTeXt-item-list "\\b\\|") "\\b\\)"))
+;; Backward compatibility.
+(defalias 'ConTeXt-paragraph-commands-regexp
+  #'ConTeXt-paragraph-commands-regexp-make)
+
+(defun ConTeXt-set-paragraph-start ()
+  "Set `paragraph-start'."
+  (setq paragraph-start
+        (concat
+         "[ \t]*\\(?:"
+         LaTeX-paragraph-commands-regexp "\\|"
+         "\\$\\$\\|" ; Plain TeX display math
+         "$\\)")))
+
+(defun ConTeXt-paragraph-commands-add-locally (commands)
+  "Make COMMANDS be recognized as paragraph commands.
+COMMANDS can be a single string or a list of strings which will be added
+to `ConTeXt-extra-paragraph-commands'.  Additionally
+`LaTeX-paragraph-commands-regexp' will be updated.
+This is mainly a convenience function which can be used in style files."
+  (unless (listp commands) (setq commands (list commands)))
+  (dolist (elt commands)
+    (add-to-list 'ConTeXt-extra-paragraph-commands elt))
+  (setq-local LaTeX-paragraph-commands-regexp
+              (ConTeXt-paragraph-commands-regexp-make))
+  (ConTeXt-set-paragraph-start))
 
 
 ;; Outline support
@@ -1747,8 +1787,13 @@ Use `ConTeXt-Mark-version' to choose the command."
    ((string= ConTeXt-Mark-version "IV")
     (concat
      (if TeX-source-correlate-mode
-         "--synctex=1 ")
-     (unless TeX-interactive-mode
+         "--synctex=repeat ")
+     ;; Omit nonstop option when we set synctex option.  According to
+     ;; Jim <zlists+context@jdvb.ca> in bug#70399 report,
+     ;; "if context is called with "--nonstopmode" (or "--nonstop")
+     ;;  the "--synctex=..." request to create a synctex file is
+     ;;  over-ridden."
+     (unless (or TeX-interactive-mode TeX-source-correlate-mode)
        ConTeXt-texexec-option-nonstop)))
    ;; In any other case fall back on Mark II.
    (t
@@ -1818,11 +1863,18 @@ that is, you do _not_ have to cater for this yourself by adding \\\\\\=' or $."
 
 (TeX-abbrev-mode-setup ConTeXt-mode context-mode-abbrev-table)
 
+(defvar semantic-symref-filepattern-alist) ; Silence compiler
+(with-eval-after-load 'semantic/symref/grep
+  ;; This entry is necessary for M-? to work.
+  ;; <URL:https://lists.gnu.org/r/auctex-devel/2023-09/msg00002.html>
+  ;; <URL:https://lists.gnu.org/r/auctex-devel/2023-09/msg00005.html>
+  (push '(ConTeXt-mode "*.[tT]e[xX]") semantic-symref-filepattern-alist))
+
 (defun ConTeXt-mode-common-initialization ()
   "Initialization code that is common for all ConTeXt interfaces."
   (plain-TeX-common-initialization)
 
-  (set (make-local-variable 'TeX-style-hook-dialect) ConTeXt-dialect)
+  (setq-local TeX-style-hook-dialect ConTeXt-dialect)
 
   (require (intern (concat "context-" ConTeXt-current-interface)))
   (dolist (symbol ConTeXt-language-variable-list)
@@ -1839,17 +1891,17 @@ that is, you do _not_ have to cater for this yourself by adding \\\\\\=' or $."
       (setq ConTeXt-largest-level 2))
 
   ;; Indenting
-  (set (make-local-variable 'indent-line-function) #'ConTeXt-indent-line)
-  (set (make-local-variable 'fill-indent-according-to-mode) t)
+  (setq-local indent-line-function #'ConTeXt-indent-line)
+  (setq-local fill-indent-according-to-mode t)
 
   ;; Paragraph formatting
-  (set (make-local-variable 'LaTeX-syntactic-comments) nil)
+  (setq-local LaTeX-syntactic-comments nil)
   ;; Moved after `run-mode-hooks'. (bug#65750)
   ;; (set (make-local-variable 'LaTeX-paragraph-commands-regexp)
   ;;      (ConTeXt-paragraph-commands-regexp))
-  (set (make-local-variable 'paragraph-ignore-fill-prefix) t)
-  (set (make-local-variable 'fill-paragraph-function) #'LaTeX-fill-paragraph)
-  (set (make-local-variable 'adaptive-fill-mode) nil)
+  (setq-local paragraph-ignore-fill-prefix t)
+  (setq-local fill-paragraph-function #'LaTeX-fill-paragraph)
+  (setq-local adaptive-fill-mode nil)
   ;; Moved after `run-mode-hooks'. (bug#65750)
   ;; (setq paragraph-start
   ;;       (concat
@@ -1874,18 +1926,18 @@ that is, you do _not_ have to cater for this yourself by adding \\\\\\=' or $."
 
   ;; Outline support
   (require 'outline)
-  (set (make-local-variable 'outline-level) #'ConTeXt-outline-level)
-  (set (make-local-variable 'outline-regexp) (ConTeXt-outline-regexp t))
+  (setq-local outline-level #'ConTeXt-outline-level)
+  (setq-local outline-regexp (ConTeXt-outline-regexp t))
   (make-local-variable 'outline-heading-end-regexp)
   (setq TeX-header-end (ConTeXt-header-end)
         TeX-trailer-start (ConTeXt-trailer-start))
 
   ;; font switch support
-  (set (make-local-variable 'TeX-font-list) ConTeXt-font-list)
+  (setq-local TeX-font-list ConTeXt-font-list)
 
   ;; imenu support
-  (set (make-local-variable 'imenu-create-index-function)
-       #'ConTeXt-imenu-create-index-function)
+  (setq-local imenu-create-index-function
+              #'ConTeXt-imenu-create-index-function)
 
   (setq TeX-command-default "ConTeXt")
   (setq TeX-sentinel-default-function #'TeX-ConTeXt-sentinel))
@@ -1903,16 +1955,11 @@ Run after mode hooks and file local variables application."
                    (mapconcat #'identity ConTeXt-item-list "\\|")
                    "\\)\\>")))
 
-  ;; Don't do locally-bound test for `LaTeX-paragraph-commands-regexp'
-  ;; and `paragraph-start'.  See comments in similar part in latex.el.
   (setq-local LaTeX-paragraph-commands-regexp
-              (ConTeXt-paragraph-commands-regexp))
-  (setq paragraph-start
-        (concat
-         "[ \t]*\\("
-         (ConTeXt-paragraph-commands-regexp) "\\|"
-         "\\$\\$\\|" ; Plain TeX display math
-         "$\\)")))
+              (ConTeXt-paragraph-commands-regexp-make))
+  ;; Don't do locally-bound test for `paragraph-start'.  See comments in
+  ;; similar part in latex.el.
+  (ConTeXt-set-paragraph-start))
 
 (defun context-guess-current-interface ()
   "Guess what ConTeXt interface the current buffer is using."
