@@ -1,6 +1,6 @@
 ;;; floatrow.el --- AUCTeX style for `floatrow.sty' (v0.3b)  -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2017--2020 Free Software Foundation, Inc.
+;; Copyright (C) 2017--2024 Free Software Foundation, Inc.
 
 ;; Author: Arash Esbati <arash@gnu.org>
 ;; Maintainer: auctex-devel@gnu.org
@@ -62,11 +62,8 @@
 (eval-when-compile
   (require 'cl-lib))
 
-;; Needed for compiling `LaTeX-check-insert-macro-default-style':
-(require 'latex)
-
-;; Needed for auto-parsing:
 (require 'tex)
+(require 'latex)
 
 ;; Silence the compiler:
 (declare-function font-latex-add-keywords
@@ -146,9 +143,74 @@
     ("LTcapwidth" ("table" "contents")))
   "Key=value options for floatrow macros and environments.")
 
-(defvar LaTeX-floatrow-key-val-options-local nil
-  "Buffer-local key=value options for floatrow macros and environments.")
-(make-variable-buffer-local 'LaTeX-floatrow-key-val-options-local)
+(defun LaTeX-floatrow-key-val-options ()
+  "Return an updated list of key=vals from floatrow package."
+  (append
+   (when (LaTeX-floatrow-DeclareNewOption-list)
+     (let ((vcode-keys '("precode" "rowprecode" "midcode" "postcode" "rowpostcode"))
+           (sep-keys '("floatrowsep" "capbesidesep"))
+           result)
+       (dolist (keyvals (LaTeX-floatrow-DeclareNewOption-list) result)
+         (let* ((key (cond ((string= (nth 1 keyvals) "FloatStyle")
+                            "style")
+                           ((string= (nth 1 keyvals) "FloatFont")
+                            "font")
+                           ((string= (nth 1 keyvals) "FloatVCode")
+                            "precode")
+                           ((string= (nth 1 keyvals) "ColorBox")
+                            "colorframeset")
+                           ((string= (nth 1 keyvals) "CBoxCorners")
+                            "colorframecorners")
+                           ((string= (nth 1 keyvals) "ObjectSet")
+                            "objectset")
+                           ((string= (nth 1 keyvals) "MarginSet")
+                            "margins")
+                           ((string= (nth 1 keyvals) "FloatSeparators")
+                            "floatrowsep")
+                           ((string= (nth 1 keyvals) "FloatFootnoterule")
+                            "footnoterule")
+                           (t nil)))
+                (val (nth 2 keyvals))
+                (vals-predefined
+                 (cadr (assoc key LaTeX-floatrow-key-val-options)))
+                (vals-parsed (cadr (assoc key result))))
+           ;; Remove entry in `result' if there is one for the `key'.
+           ;; `precode' and `floatrowsep' are special here since they
+           ;; are placeholders for other keys (see above):
+           (cond ((string= key "precode")
+                  (dolist (x vcode-keys)
+                    (when (assoc x result)
+                      (setq result (assq-delete-all (car (assoc x result)) result)))))
+                 ((string= key "floatrowsep")
+                  (dolist (x sep-keys)
+                    (when (assoc x result)
+                      (setq result (assq-delete-all (car (assoc x result)) result)))))
+                 (t
+                  (when (assoc key result)
+                    (setq result (assq-delete-all (car (assoc key result)) result)))))
+           ;; Add the entrie to `result'.  Again, watch for `precode'
+           ;; and `floatrowsep'.  Also delete any dupes:
+           (cond ((string= key "precode")
+                  (dolist (x vcode-keys)
+                    (cl-pushnew (list x (TeX-delete-duplicate-strings
+                                         (append vals-parsed
+                                                 vals-predefined
+                                                 (list val))))
+                                result :test #'equal)))
+                 ((string= key "floatrowsep")
+                  (dolist (x sep-keys)
+                    (cl-pushnew (list x (TeX-delete-duplicate-strings
+                                         (append vals-parsed
+                                                 vals-predefined
+                                                 (list val))))
+                                result :test #'equal)))
+                 (t
+                  (cl-pushnew (list key (TeX-delete-duplicate-strings
+                                         (append vals-parsed
+                                                 vals-predefined
+                                                 (list val))))
+                              result :test #'equal)))))))
+   LaTeX-floatrow-key-val-options))
 
 (defvar LaTeX-floatrow-supported-float-types
   '("figure" "table"                              ; Standard LaTeX
@@ -228,14 +290,23 @@
   ;; Replace initially the way fig & tab env's are inserted:
   (LaTeX-floatrow-env-init)
   ;;
-  ;; Process new key=val options:
-  (when (LaTeX-floatrow-DeclareNewOption-list)
-    (LaTeX-floatrow-update-key-val-options))
-  ;;
   ;; Process new float commands like \ffigbox:
   (when (LaTeX-floatrow-newfloatcommand-list)
     (dolist (cmd (mapcar #'car (LaTeX-floatrow-newfloatcommand-list)))
-      (TeX-add-symbols `(,cmd LaTeX-floatrow-arg-floatbox))
+      (TeX-add-symbols
+       `(,cmd
+         [TeX-arg-completing-read ,(lambda ()
+                                     (mapcar (lambda (x)(concat TeX-esc (car x)))
+                                             (LaTeX-length-list)))
+                                  "Width"]
+         [TeX-arg-completing-read ,(lambda ()
+                                     (mapcar (lambda (x)
+                                               (concat TeX-esc (car x)))
+                                             (LaTeX-length-list)))
+                                  "Height"]
+         [TeX-arg-completing-read ("t" "c" "b" "s")
+                                  "Vertical alignment"]
+         LaTeX-floatrow-arg-floatbox))
       (when (and (featurep 'font-latex)
                  (eq TeX-install-font-lock 'font-latex-setup))
         (font-latex-add-keywords `((,cmd "[[["))
@@ -291,97 +362,13 @@
 (add-hook 'TeX-auto-cleanup-hook #'LaTeX-floatrow-auto-cleanup t)
 (add-hook 'TeX-update-style-hook #'TeX-auto-parse t)
 
-(defun LaTeX-floatrow-update-key-val-options ()
-  "Update buffer-local key-val options before offering for completion."
-  (let ((vcode-keys '("precode" "rowprecode" "midcode" "postcode" "rowpostcode"))
-        (sep-keys '("floatrowsep" "capbesidesep")))
-    (dolist (keyvals (LaTeX-floatrow-DeclareNewOption-list))
-      (let* ((key (cond ((string= (nth 1 keyvals) "FloatStyle")
-                         "style")
-                        ((string= (nth 1 keyvals) "FloatFont")
-                         "font")
-                        ((string= (nth 1 keyvals) "FloatVCode")
-                         "precode")
-                        ((string= (nth 1 keyvals) "ColorBox")
-                         "colorframeset")
-                        ((string= (nth 1 keyvals) "CBoxCorners")
-                         "colorframecorners")
-                        ((string= (nth 1 keyvals) "ObjectSet")
-                         "objectset")
-                        ((string= (nth 1 keyvals) "MarginSet")
-                         "margins")
-                        ((string= (nth 1 keyvals) "FloatSeparators")
-                         "floatrowsep")
-                        ((string= (nth 1 keyvals) "FloatFootnoterule")
-                         "footnoterule")
-                        (t nil)))
-             (val (nth 2 keyvals))
-             (val-match (cadr (assoc key LaTeX-floatrow-key-val-options-local)))
-             (temp (copy-alist LaTeX-floatrow-key-val-options-local))
-             (opts (cond ((string= key "precode")
-                          (dolist (x vcode-keys)
-                            (setq temp (assq-delete-all (car (assoc x temp)) temp)))
-                          temp)
-                         ((string= key "floatrowsep")
-                          (dolist (x sep-keys)
-                            (setq temp (assq-delete-all (car (assoc x temp)) temp)))
-                          temp)
-                         (t
-                          (assq-delete-all (car (assoc key temp)) temp)))))
-        (cond ((string= key "precode")
-               (dolist (x vcode-keys)
-                 (cl-pushnew (list x (TeX-delete-duplicate-strings (append (list val) val-match)))
-                             opts :test #'equal)))
-              ((string= key "floatrowsep")
-               (dolist (x sep-keys)
-                 (cl-pushnew (list x (TeX-delete-duplicate-strings (append (list val) val-match)))
-                             opts :test #'equal)))
-              (t
-               (cl-pushnew (list key (TeX-delete-duplicate-strings (append (list val) val-match)))
-                           opts :test #'equal)))
-        (setq LaTeX-floatrow-key-val-options-local (copy-alist opts))))))
-
 (defun LaTeX-floatrow-arg-floatbox (optional)
   "Query and insert arguments of float box commands from floatrow.sty.
 If OPTIONAL is non-nil, indicate optional argument during query."
-  ;; Query for the optional arguments; ask for "vertpos" only if
-  ;; "height" is given.  let-bind `TeX-arg-*-brace' for
-  ;; `TeX-argument-insert':
-  (let* ((TeX-arg-opening-brace "[")
-         (TeX-arg-closing-brace "]")
-         (TeX-last-optional-rejected nil)
-         (width (LaTeX-check-insert-macro-default-style
-                 (completing-read
-                  (TeX-argument-prompt t nil "Width")
-                  (mapcar (lambda (x) (concat TeX-esc (car x)))
-                          (LaTeX-length-list)))))
-         (TeX-last-optional-rejected (or (not width)
-                                         (and width (string= width ""))))
-         (height (LaTeX-check-insert-macro-default-style
-                  (completing-read
-                   (TeX-argument-prompt t nil "Height")
-                   (mapcar (lambda (x) (concat TeX-esc (car x)))
-                           (LaTeX-length-list)))))
-         (TeX-last-optional-rejected (or (not height)
-                                         (and height (string= height ""))))
-         (vertpos (LaTeX-check-insert-macro-default-style
-                   (if (string= height "")
-                       ""
-                     (completing-read
-                      (TeX-argument-prompt t nil "Vertical alignment")
-                      '("t" "c" "b" "s"))))))
-    (and width (TeX-argument-insert width t))
-    ;; Insert an extra pair of brackets if only `height' is given,
-    ;; otherwise it will become `width'
-    (when (and width (string= width "")
-               height (not (string= height "")))
-      (insert "[]"))
-    (and height (TeX-argument-insert height t))
-    (and vertpos (TeX-argument-insert vertpos t)))
-  ;; Now query for the (short-)caption.  Also check for the
-  ;; float-type; if we're inside (sub)?floatrow*?, then check for the
-  ;; next outer environment:
-  (let* ((currenv (if (string-match "floatrow\\*?\\_>" (LaTeX-current-environment))
+  ;; Query for the (short-)caption.  Also check for the float-type; if
+  ;; we're inside (sub)?floatrow*?, then check for the next outer
+  ;; environment:
+  (let* ((currenv (if (string-match "floatrow\\*?\\'" (LaTeX-current-environment))
                       (LaTeX-current-environment 2)
                     (LaTeX-current-environment)))
          (caption (TeX-read-string
@@ -477,10 +464,9 @@ a string and corresponds to first parsed element in
     (LaTeX-add-floatrow-DeclareNewOptions
      (list (concat TeX-esc "Declare" key TeX-grop val TeX-grcl)
            key val))
-    (LaTeX-floatrow-update-key-val-options)
     (TeX-argument-insert val optional)
     (TeX-argument-insert
-     (TeX-read-key-val optional LaTeX-floatrow-key-val-options-local) optional)))
+     (TeX-read-key-val optional (LaTeX-floatrow-key-val-options)) optional)))
 
 (defun LaTeX-floatrow-arg-newseparatedlabel/ref (optional type)
   "Query and insert user defined label and reference macros from floatrow.sty.
@@ -497,7 +483,7 @@ the string \"label\" or \"ref\"."
     (TeX-argument-insert cmd optional TeX-esc)))
 
 (defun LaTeX-floatrow-arg-declare-new-floattype (optional &optional cleanup)
-  "Query and insert the first argument of \"DeclareNewFloatType\" macro from floatrow.sty.
+  "Query and insert the first argument of \"DeclareNewFloatType\" macro.
 If OPTIONAL is non-nil, insert the argument in brackets.  If
 CLEANUP in non-nil, skip the query and insert process as we are
 inside the function `LaTeX-floatrow-auto-cleanup' and process
@@ -543,10 +529,6 @@ only the parsed items."
    (TeX-auto-add-regexp LaTeX-floatrow-newseparatedlabel-ref-regexp)
    (TeX-auto-add-regexp LaTeX-floatrow-DeclareNewFloatType-regexp)
 
-   ;; Activate the buffer-local version of key-vals
-   (setq LaTeX-floatrow-key-val-options-local
-         (copy-alist LaTeX-floatrow-key-val-options))
-
    ;; Add pre-defined float commands:
    (LaTeX-add-floatrow-newfloatcommands
     "ffigbox" "fcapside" "ttabbox")
@@ -555,48 +537,101 @@ only the parsed items."
    (TeX-add-symbols
     ;; 2.1 The \floatbox Macro
     ;; \floatbox[<preamble>]{<captype>}[<width>][<height>][<vert pos>]{<caption>}{<object>}
-    '("floatbox"
-      [ TeX-arg-eval completing-read
-        (TeX-argument-prompt t nil "Preamble")
-        '("\\capbeside" "\\nocapbeside" "\\captop") ]
-      (TeX-arg-eval completing-read
-                    (TeX-argument-prompt nil nil "Float type")
-                    LaTeX-floatrow-supported-float-types)
+    `("floatbox"
+      [TeX-arg-completing-read ("\\capbeside" "\\nocapbeside" "\\captop")
+                               "Preamble"]
+      (TeX-arg-completing-read LaTeX-floatrow-supported-float-types
+                               "Float type")
+      [TeX-arg-completing-read ,(lambda ()
+                                  (mapcar (lambda (x)
+                                            (concat TeX-esc (car x)))
+                                          (LaTeX-length-list)))
+                               "Width"]
+      [TeX-arg-completing-read ,(lambda ()
+                                  (mapcar (lambda (x)
+                                            (concat TeX-esc (car x)))
+                                          (LaTeX-length-list)))
+                               "Height"]
+      [TeX-arg-completing-read ("t" "c" "b" "s")
+                               "Vertical alignment"]
       LaTeX-floatrow-arg-floatbox)
 
     ;; 2.2 Creation of Personal Commands for Float Boxes
-    '("newfloatcommand"
-      (TeX-arg-eval
-       (lambda ()
+    `("newfloatcommand"
+      ,(lambda (optional)
          (let ((cmd (TeX-read-string
-                     (TeX-argument-prompt nil nil "Command"))))
+                     (TeX-argument-prompt optional nil "Command"))))
            (LaTeX-add-floatrow-newfloatcommands cmd)
            (TeX-add-symbols
-            `(,cmd LaTeX-floatrow-arg-floatbox))
-           (format "%s" cmd))))
-      (TeX-arg-eval completing-read
-                    (TeX-argument-prompt nil nil "Float type")
-                    '("figure" "table"))
+            `(,cmd [TeX-arg-completing-read
+                    ,(lambda ()
+                       (mapcar (lambda (x)
+                                 (concat TeX-esc (car x)))
+                               (LaTeX-length-list)))
+                    "Width"]
+                   [TeX-arg-completing-read
+                    ,(lambda ()
+                       (mapcar (lambda (x)
+                                 (concat TeX-esc (car x)))
+                               (LaTeX-length-list)))
+                    "Height"]
+                   [TeX-arg-completing-read ("t" "c" "b" "s")
+                                            "Vertical alignment"]
+                   LaTeX-floatrow-arg-floatbox))
+           (TeX-argument-insert cmd optional)))
+      (TeX-arg-completing-read ("figure" "table") "Float type")
       [ 2 ])
 
     '("renewfloatcommand"
-      (TeX-arg-eval completing-read
-                    (TeX-argument-prompt nil nil "Command")
-                    (LaTeX-floatrow-newfloatcommand-list))
-      (TeX-arg-eval completing-read
-                    (TeX-argument-prompt nil nil "Float type")
-                    '("figure" "table"))
+      (TeX-arg-completing-read (LaTeX-floatrow-newfloatcommand-list)
+                               "Command")
+      (TeX-arg-completing-read ("figure" "table") "Float type")
       [ 2 ])
 
-
     ;; 2.2.2 Predefined Float Box Commands
-    '("ffigbox"
+    `("ffigbox"
+      [TeX-arg-completing-read ,(lambda ()
+                                  (mapcar (lambda (x)
+                                            (concat TeX-esc (car x)))
+                                          (LaTeX-length-list)))
+                               "Width"]
+      [TeX-arg-completing-read ,(lambda ()
+                                  (mapcar (lambda (x)
+                                            (concat TeX-esc (car x)))
+                                          (LaTeX-length-list)))
+                               "Height"]
+      [TeX-arg-completing-read ("t" "c" "b" "s")
+                               "Vertical alignment"]
       LaTeX-floatrow-arg-floatbox)
 
-    '("ttabbox"
+    `("ttabbox"
+      [TeX-arg-completing-read ,(lambda ()
+                                  (mapcar (lambda (x)
+                                            (concat TeX-esc (car x)))
+                                          (LaTeX-length-list)))
+                               "Width"]
+      [TeX-arg-completing-read ,(lambda ()
+                                  (mapcar (lambda (x)
+                                            (concat TeX-esc (car x)))
+                                          (LaTeX-length-list)))
+                               "Height"]
+      [TeX-arg-completing-read ("t" "c" "b" "s")
+                               "Vertical alignment"]
       LaTeX-floatrow-arg-floatbox)
 
-    '("fcapside"
+    `("fcapside"
+      [TeX-arg-completing-read ,(lambda ()
+                                  (mapcar (lambda (x)
+                                            (concat TeX-esc (car x)))
+                                          (LaTeX-length-list)))
+                               "Width"]
+      [TeX-arg-completing-read ,(lambda ()
+                                  (mapcar (lambda (x)
+                                            (concat TeX-esc (car x)))
+                                          (LaTeX-length-list)))
+                               "Height"]
+      [TeX-arg-completing-read ("t" "c" "b" "s")
+                               "Vertical alignment"]
       LaTeX-floatrow-arg-floatbox)
 
     ;; 2.3.1 Mixed Row
@@ -608,20 +643,18 @@ only the parsed items."
 
     ;; 3 Float Layout Settings
     '("floatsetup"
-      [ TeX-arg-eval completing-read
-        (TeX-argument-prompt t nil "Float type")
-        LaTeX-floatrow-supported-float-types ]
-      (TeX-arg-key-val LaTeX-floatrow-key-val-options-local))
+      [TeX-arg-completing-read LaTeX-floatrow-supported-float-types
+                               "Float type"]
+      (TeX-arg-key-val (LaTeX-floatrow-key-val-options)))
 
     ;; 3.2 Settings for Current Float Environment
     '("thisfloatsetup"
-      (TeX-arg-key-val LaTeX-floatrow-key-val-options-local))
+      (TeX-arg-key-val (LaTeX-floatrow-key-val-options)))
 
     ;; 3.3 Clearing of Settings for Current Float Type
     '("clearfloatsetup"
-      (TeX-arg-eval completing-read
-                    (TeX-argument-prompt nil nil "Float type")
-                    LaTeX-floatrow-supported-float-types))
+      (TeX-arg-completing-read LaTeX-floatrow-supported-float-types
+                               "Float type"))
 
     ;; 3.4 Temporary Clearing of All Float Settings
     '("killfloatstyle" 0)
