@@ -1,6 +1,6 @@
-;;; simpleicons.el --- AUCTeX style for `simpleicons.sty' (v10.4.0)  -*- lexical-binding: t; -*-
+;;; simpleicons.el --- AUCTeX style for `simpleicons.sty' (v12.4.0)  -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2023 Free Software Foundation, Inc.
+;; Copyright (C) 2023--2024 Free Software Foundation, Inc.
 
 ;; Author: Arash Esbati <arash@gnu.org>
 ;; Maintainer: auctex-devel@gnu.org
@@ -26,8 +26,8 @@
 
 ;;; Commentary:
 
-;; This file adds support for `simpleicons.sty' (v10.4.0) from
-;; 2023/12/29.  `simpleicons.sty' is part of TeXLive.
+;; This file adds support for `simpleicons.sty' (v12.4.0) from
+;; 2024/06/28.  `simpleicons.sty' is part of TeXLive.
 
 ;;; Code:
 
@@ -41,12 +41,18 @@
 
 (defvar LaTeX-simpleicons-icons
   '("1001tracklists"
+    "1dot1dot1dot1"
+    "1panel"
     "1password"
+    "2fas"
+    "2k"
+    "365datascience"
     "3m"
     "42"
     "4chan"
     "4d"
     "500px"
+    "7zip"
     "99designs"
     "9gag"
     "abbott"
@@ -54,6 +60,7 @@
     "abbvie"
     "aboutdotme"
     "abstract"
+    "abusedotch"
     "academia"
     "accenture"
     "accusoft"
@@ -62,6 +69,7 @@
     "actigraph"
     "activision"
     "activitypub"
+    "actix"
     "acura"
     "adafruit"
     "adblock"
@@ -88,6 +96,7 @@
     "adroll"
     "adventofcode"
     "adyen"
+    "aegisauthenticator"
     "aerlingus"
     "aeroflot"
     "aeromexico"
@@ -107,7 +116,7 @@
     "aiqfome"
     "airasia"
     "airbnb"
-    "airbrakedotio"
+    "airbrake"
     "airbus"
     "airbyte"
     "aircall"
@@ -119,9 +128,11 @@
     "airplayvideo"
     "airtable"
     "airtel"
+    "airtransat"
     "ajv"
     "akamai"
     "akaunting"
+    "akiflow"
     "alacritty"
     "alamy"
     "albertheijn"
@@ -148,16 +159,18 @@
     "alteryx"
     "altiumdesigner"
     "alwaysdata"
+    "alx"
     "amazon"
     "amazonalexa"
     "amazonapigateway"
-    "amazonaws"
     "amazoncloudwatch"
+    "amazoncognito"
     "amazondocumentdb"
     "amazondynamodb"
     "amazonec2"
     "amazonecs"
     "amazoneks"
+    "amazonelasticache"
     "amazonfiretv"
     "amazongames"
     "amazoniam"
@@ -172,6 +185,7 @@
     "amazons3"
     "amazonsimpleemailservice"
     "amazonsqs"
+    "amazonwebservices"
     "amd"
     "ameba"
     "americanairlines"
@@ -188,13 +202,19 @@
     "androidstudio"
     "angular"
     "anilist"
+    "animalplanet"
+    "ankermake"
+    "anki"
     "ansible"
     "answer"
     "ansys"
     "anta"
     "antdesign"
     "antena3"
+    "anthropic"
+    "anycubic"
     "anydesk"
+    "anytype"
     "aol"
     "apache"
     "apacheairflow"
@@ -206,9 +226,11 @@
     "apachedruid"
     "apacheecharts"
     "apacheflink"
+    "apachefreemarker"
     "apachegroovy"
     "apacheguacamole"
     "apachehadoop"
+    "apachehbase"
     "apachehive"
     "apachejmeter"
     "apachekafka"
@@ -222,6 +244,7 @@
     "apachesolr"
     "apachespark"
     "apachestorm"
+    "apachesuperset"
     "apachetomcat"
     "aparat"
     "apifox"
@@ -229,6 +252,7 @@
     "apollographql"
     "apostrophe"
     "appian"
+    "appium"
     "apple"
     "applearcade"
     "applemusic"
@@ -263,6 +287,7 @@
     "artixlinux"
     "artstation"
     "arxiv"
+    "asahilinux"
     "asana"
     "asciidoctor"
     "asciinema"
@@ -270,7 +295,10 @@
     "aseprite"
     "askfm"
     "assemblyscript"
+    "asterisk"
     "astonmartin"
+    "astra"
+    "astral"
     "astro"
     "asus"
     "atandt"
@@ -280,14 +308,17 @@
     "audacity"
     "audi"
     "audible"
+    "audiobookshelf"
     "audioboom"
     "audiomack"
     "audiotechnica"
     "aurelia"
     "auth0"
     "authelia"
+    "authentik"
     "authy"
     "autocad"
+    "autocannon"
     "autodesk"
     "autodeskmaya"
     "autodeskrevit"
@@ -295,6 +326,7 @@
     "autoit"
     "automattic"
     "autoprefixer"
+    "autozone"
     "avajs"
     "avast"
     "avianca"
@@ -302,9 +334,12 @@
     "awesomelists"
     "awesomewm"
     "awsamplify"
+    "awselasticloadbalancing"
     "awsfargate"
     "awslambda"
     "awsorganizations"
+    "awssecretsmanager"
+    "awwwards"
     "axios"
     "azureartifacts"
     "azuredataexplorer"
@@ -312,6 +347,7 @@
     "azurefunctions"
     "azurepipelines"
     "babel"
+    "babelio"
     "babylondotjs"
     "backblaze"
     "backbonedotjs"
@@ -321,6 +357,7 @@
     "baidu"
     "bakalari"
     "bamboo"
+    "bambulab"
     "bandcamp"
     "bandlab"
     "bandrautomation"
@@ -332,19 +369,25 @@
     "basecamp"
     "basicattentiontoken"
     "bastyon"
+    "bat"
     "bata"
     "battledotnet"
+    "bazel"
     "beatport"
     "beats"
     "beatsbydre"
+    "beatstars"
+    "beekeeperstudio"
     "behance"
     "beijingsubway"
     "bem"
     "bentley"
     "bento"
+    "bentobox"
     "bentoml"
     "bereal"
     "betfair"
+    "betterstack"
     "bevy"
     "bigbasket"
     "bigbluebutton"
@@ -380,11 +423,13 @@
     "bloglovin"
     "blueprint"
     "bluesky"
+    "bluesound"
     "bluetooth"
     "bmcsoftware"
     "bmw"
     "bnbchain"
     "boardgamegeek"
+    "boat"
     "boehringeringelheim"
     "boeing"
     "bombardier"
@@ -405,14 +450,17 @@
     "bower"
     "box"
     "boxysvg"
+    "braintree"
     "brandfolder"
     "brave"
     "breaker"
+    "brenntag"
     "brevo"
     "brex"
     "bricks"
     "britishairways"
     "broadcom"
+    "bruno"
     "bsd"
     "bspwm"
     "bt"
@@ -423,14 +471,18 @@
     "bugatti"
     "bugcrowd"
     "bugsnag"
+    "buhl"
     "buildkite"
     "bukalapak"
     "bulma"
     "bun"
+    "bungie"
     "bunq"
     "burgerking"
+    "burpsuite"
     "burton"
     "buymeacoffee"
+    "buysellads"
     "buzzfeed"
     "bvg"
     "byjus"
@@ -444,13 +496,17 @@
     "cairographics"
     "cairometro"
     "cakephp"
+    "caldotcom"
     "calendly"
+    "calibreweb"
     "campaignmonitor"
+    "camunda"
     "canonical"
     "canva"
     "canvas"
     "capacitor"
     "cardano"
+    "carlsberggroup"
     "carrd"
     "carrefour"
     "carthrottle"
@@ -484,8 +540,10 @@
     "checkmarx"
     "checkmk"
     "chedraui"
+    "cheerio"
     "chef"
     "chemex"
+    "chessdotcom"
     "chevrolet"
     "chianetwork"
     "chinaeasternairlines"
@@ -524,14 +582,18 @@
     "cloudera"
     "cloudflare"
     "cloudflarepages"
+    "cloudflareworkers"
     "cloudfoundry"
     "cloudinary"
+    "cloudron"
     "cloudsmith"
     "cloudways"
+    "clubforce"
     "clubhouse"
     "clyp"
     "cmake"
     "cncf"
+    "cnet"
     "cnn"
     "cocacola"
     "cockpit"
@@ -549,6 +611,7 @@
     "codecov"
     "codefactor"
     "codeforces"
+    "codefresh"
     "codeigniter"
     "codeium"
     "codemagic"
@@ -557,6 +620,7 @@
     "codenewbie"
     "codepen"
     "codeproject"
+    "coder"
     "codersrank"
     "coderwall"
     "codesandbox"
@@ -574,6 +638,7 @@
     "coinbase"
     "coinmarketcap"
     "comicfury"
+    "comma"
     "commerzbank"
     "commitlint"
     "commodore"
@@ -594,12 +659,16 @@
     "contao"
     "contentful"
     "contentstack"
+    "contributorcovenant"
     "conventionalcommits"
     "convertio"
     "cookiecutter"
+    "coolermaster"
     "coop"
+    "copaairlines"
     "coppel"
     "cora"
+    "coreldraw"
     "coronaengine"
     "coronarenderer"
     "corsair"
@@ -628,9 +697,11 @@
     "crunchbase"
     "crunchyroll"
     "cryengine"
+    "cryptpad"
     "crystal"
     "csharp"
     "css3"
+    "cssdesignawards"
     "cssmodules"
     "csswizardry"
     "cts"
@@ -669,8 +740,11 @@
     "datastax"
     "dataverse"
     "datefns"
+    "datev"
     "datocms"
     "datto"
+    "davinciresolve"
+    "dazhongdianping"
     "dazn"
     "dbeaver"
     "dblp"
@@ -678,7 +752,10 @@
     "dcentertainment"
     "debian"
     "decapcms"
+    "decentraland"
     "dedge"
+    "deepcool"
+    "deepgram"
     "deepin"
     "deepl"
     "deepnote"
@@ -709,6 +786,7 @@
     "diagramsdotnet"
     "dialogflow"
     "diaspora"
+    "dictionarydotcom"
     "digg"
     "digikeyelectronics"
     "digitalocean"
@@ -730,17 +808,20 @@
     "docker"
     "docsdotrs"
     "docsify"
+    "doctrine"
     "docusaurus"
     "docusign"
     "dogecoin"
     "doi"
     "dolby"
     "doordash"
+    "dota2"
     "dotenv"
     "dotnet"
     "douban"
     "doubanread"
     "dovecot"
+    "dovetail"
     "doxygen"
     "dpd"
     "dragonframe"
@@ -762,6 +843,7 @@
     "dunked"
     "dunzo"
     "duolingo"
+    "duplicati"
     "dvc"
     "dwavesystems"
     "dwm"
@@ -781,13 +863,16 @@
     "eclipsejetty"
     "eclipsemosquitto"
     "eclipsevertdotx"
+    "ecovacs"
     "edeka"
+    "edgeimpulse"
     "editorconfig"
     "edotleclerc"
     "educative"
     "edx"
     "egghead"
     "egnyte"
+    "eight"
     "eightsleep"
     "ejs"
     "elastic"
@@ -798,6 +883,7 @@
     "electron"
     "electronbuilder"
     "electronfiddle"
+    "elegoo"
     "element"
     "elementary"
     "elementor"
@@ -815,6 +901,7 @@
     "emirates"
     "emlakjet"
     "empirekred"
+    "endeavouros"
     "engadget"
     "enpass"
     "enterprisedb"
@@ -824,6 +911,7 @@
     "epicgames"
     "epson"
     "equinixmetal"
+    "eraser"
     "ericsson"
     "erlang"
     "erpnext"
@@ -831,17 +919,20 @@
     "esea"
     "eslgaming"
     "eslint"
+    "esotericsoftware"
     "esphome"
     "espressif"
     "esri"
     "etcd"
     "ethereum"
+    "ethers"
     "ethiopianairlines"
     "etihadairways"
     "etsy"
     "eventbrite"
     "eventstore"
     "evernote"
+    "excalidraw"
     "exercism"
     "exordo"
     "exoscale"
@@ -867,6 +958,7 @@
     "fandom"
     "fanfou"
     "fantom"
+    "farcaster"
     "fareharbor"
     "farfetch"
     "fastapi"
@@ -893,6 +985,7 @@
     "figma"
     "figshare"
     "fila"
+    "filedotio"
     "files"
     "filezilla"
     "fineco"
@@ -905,15 +998,16 @@
     "fireship"
     "firewalla"
     "first"
+    "fishshell"
     "fitbit"
-    "fite"
     "fivem"
     "fiverr"
+    "fizz"
+    "flashforge"
     "flask"
     "flat"
     "flathub"
     "flatpak"
-    "flattr"
     "flickr"
     "flightaware"
     "flipboard"
@@ -934,14 +1028,18 @@
     "fontawesome"
     "fontbase"
     "fontforge"
+    "foobar2000"
     "foodpanda"
     "ford"
     "forgejo"
+    "formik"
+    "formspree"
     "formstack"
     "fortinet"
     "fortran"
     "fossa"
     "fossilscm"
+    "foundryvirtualtabletop"
     "foursquare"
     "foursquarecityguide"
     "fox"
@@ -954,33 +1052,41 @@
     "frappe"
     "fraunhofergesellschaft"
     "freebsd"
+    "freecad"
     "freecodecamp"
     "freedesktopdotorg"
     "freelancer"
+    "freelancermap"
     "freenas"
     "freepik"
     "frontendmentor"
     "frontify"
     "fsecure"
     "fsharp"
+    "fubo"
+    "fueler"
     "fugacloud"
     "fujifilm"
     "fujitsu"
     "funimation"
     "furaffinity"
     "furrynetwork"
+    "fusionauth"
     "futurelearn"
     "g2"
     "g2a"
+    "g2g"
     "galaxus"
     "gameandwatch"
     "gamebanana"
     "gamedeveloper"
     "gamejolt"
+    "gameloft"
     "gamemaker"
     "garmin"
     "gatling"
     "gatsby"
+    "gcore"
     "gdal"
     "geant"
     "geeksforgeeks"
@@ -989,6 +1095,8 @@
     "genius"
     "gentoo"
     "geocaching"
+    "geode"
+    "geopandas"
     "gerrit"
     "getx"
     "ghost"
@@ -998,9 +1106,11 @@
     "giphy"
     "git"
     "gitbook"
+    "gitconnected"
     "gitea"
     "gitee"
     "gitextensions"
+    "gitforwindows"
     "github"
     "githubactions"
     "githubcopilot"
@@ -1013,6 +1123,7 @@
     "gitpod"
     "gitter"
     "glassdoor"
+    "glide"
     "glitch"
     "globus"
     "glovo"
@@ -1031,6 +1142,7 @@
     "godotengine"
     "gofundme"
     "gogdotcom"
+    "gojek"
     "goland"
     "goldenline"
     "goldmansachs"
@@ -1042,7 +1154,7 @@
     "googleanalytics"
     "googleappsscript"
     "googleassistant"
-    "googlebard"
+    "googleauthenticator"
     "googlebigquery"
     "googlebigtable"
     "googlecalendar"
@@ -1050,6 +1162,7 @@
     "googlecardboard"
     "googlechat"
     "googlechrome"
+    "googlechronicle"
     "googleclassroom"
     "googlecloud"
     "googlecloudcomposer"
@@ -1060,6 +1173,7 @@
     "googledataflow"
     "googledataproc"
     "googledatastudio"
+    "googledisplayandvideo360"
     "googledocs"
     "googledomains"
     "googledrive"
@@ -1068,6 +1182,7 @@
     "googlefit"
     "googlefonts"
     "googleforms"
+    "googlegemini"
     "googlehangouts"
     "googlehome"
     "googlekeep"
@@ -1127,6 +1242,7 @@
     "gumtree"
     "gunicorn"
     "gurobi"
+    "gusto"
     "gutenberg"
     "h3"
     "habr"
@@ -1172,6 +1288,7 @@
     "here"
     "heroku"
     "hetzner"
+    "hevy"
     "hexlet"
     "hexo"
     "hey"
@@ -1182,11 +1299,14 @@
     "hitachi"
     "hive"
     "hiveblockchain"
+    "hivemq"
+    "homarr"
     "homeadvisor"
     "homeassistant"
     "homeassistantcommunitystore"
     "homebrew"
     "homebridge"
+    "homepage"
     "homify"
     "honda"
     "honey"
@@ -1204,22 +1324,26 @@
     "hsbc"
     "html5"
     "htmlacademy"
+    "htmx"
     "htop"
     "httpie"
     "huawei"
     "hubspot"
+    "huggingface"
     "hugo"
-    "hulu"
     "humblebundle"
     "hungryjacks"
     "husqvarna"
     "hyper"
+    "hyperskill"
     "hypothesis"
+    "hyprland"
     "hyundai"
     "i18next"
     "i3"
     "iata"
     "ibeacon"
+    "iberia"
     "ibm"
     "ibmcloud"
     "ibmwatson"
@@ -1240,21 +1364,27 @@
     "ifood"
     "ifttt"
     "igdb"
+    "ign"
     "iheartradio"
     "ikea"
     "iledefrancemobilites"
+    "imagedotsc"
     "imagej"
     "imdb"
+    "imessage"
     "imgur"
     "immer"
     "immich"
     "imou"
     "improvmx"
     "indeed"
+    "indiansuperleague"
+    "indiehackers"
     "indigo"
     "inertia"
     "infiniti"
     "influxdb"
+    "infomaniak"
     "infoq"
     "informatica"
     "infosys"
@@ -1262,6 +1392,7 @@
     "ingress"
     "inkdrop"
     "inkscape"
+    "inoreader"
     "insomnia"
     "inspire"
     "insta360"
@@ -1271,7 +1402,6 @@
     "instatus"
     "instructables"
     "instructure"
-    "integromat"
     "intel"
     "intellijidea"
     "interactiondesignfoundation"
@@ -1293,6 +1423,7 @@
     "iota"
     "ipfs"
     "iris"
+    "irobot"
     "isc2"
     "issuu"
     "istio"
@@ -1322,6 +1453,7 @@
     "jetpackcompose"
     "jfrog"
     "jfrogpipelines"
+    "jhipster"
     "jinja"
     "jira"
     "jirasoftware"
@@ -1331,6 +1463,7 @@
     "joomla"
     "joplin"
     "jordan"
+    "jouav"
     "jovian"
     "jpeg"
     "jquery"
@@ -1339,6 +1472,7 @@
     "jsfiddle"
     "json"
     "jsonwebtokens"
+    "jsr"
     "jss"
     "juce"
     "juejin"
@@ -1352,6 +1486,7 @@
     "k3s"
     "k6"
     "kaggle"
+    "kagi"
     "kahoot"
     "kaios"
     "kakao"
@@ -1369,12 +1504,14 @@
     "kde"
     "kdenlive"
     "kedro"
+    "keenetic"
     "keepachangelog"
     "keepassxc"
     "kentico"
     "keras"
     "keybase"
     "keycdn"
+    "keycloak"
     "keystone"
     "kfc"
     "khanacademy"
@@ -1395,6 +1532,9 @@
     "klm"
     "klook"
     "knative"
+    "knexdotjs"
+    "knime"
+    "knip"
     "knowledgebase"
     "known"
     "koa"
@@ -1412,10 +1552,13 @@
     "koyeb"
     "krita"
     "ktm"
+    "ktor"
     "kuaishou"
     "kubernetes"
     "kubuntu"
+    "kucoin"
     "kuma"
+    "kununu"
     "kuula"
     "kx"
     "kyocera"
@@ -1423,6 +1566,7 @@
     "lada"
     "lamborghini"
     "landrover"
+    "langchain"
     "lapce"
     "laragon"
     "laravel"
@@ -1433,6 +1577,7 @@
     "latex"
     "launchpad"
     "lazarus"
+    "lazyvim"
     "lbry"
     "leaderprice"
     "leaflet"
@@ -1442,6 +1587,7 @@
     "legacygames"
     "leica"
     "lemmy"
+    "lemonsqueezy"
     "lenovo"
     "lens"
     "leptos"
@@ -1465,6 +1611,7 @@
     "libreofficeimpress"
     "libreofficemath"
     "libreofficewriter"
+    "librewolf"
     "libuv"
     "lichess"
     "lidl"
@@ -1472,13 +1619,17 @@
     "lightburn"
     "lighthouse"
     "lightning"
+    "limesurvey"
     "line"
     "lineageos"
     "linear"
+    "lining"
     "linkedin"
     "linkerd"
     "linkfire"
+    "linksys"
     "linktree"
+    "lintcode"
     "linux"
     "linuxcontainers"
     "linuxfoundation"
@@ -1487,6 +1638,7 @@
     "linuxserver"
     "lionair"
     "liquibase"
+    "listmonk"
     "lit"
     "litecoin"
     "litiengine"
@@ -1512,6 +1664,8 @@
     "ltspice"
     "lua"
     "lubuntu"
+    "lucia"
+    "lucid"
     "ludwig"
     "lufthansa"
     "lumen"
@@ -1525,6 +1679,7 @@
     "macys"
     "magasinsu"
     "magento"
+    "magic"
     "magisk"
     "mahindra"
     "mailchimp"
@@ -1532,8 +1687,12 @@
     "maildotru"
     "mailgun"
     "mailtrap"
+    "mainwp"
     "majorleaguehacking"
+    "make"
     "makerbot"
+    "malt"
+    "malwarebytes"
     "mambaui"
     "mamp"
     "man"
@@ -1583,6 +1742,7 @@
     "mega"
     "meilisearch"
     "meituan"
+    "meizu"
     "mendeley"
     "mentorcruise"
     "mercadopago"
@@ -1595,6 +1755,7 @@
     "metabase"
     "metacritic"
     "metafilter"
+    "metasploit"
     "meteor"
     "metro"
     "metrodelaciudaddemexico"
@@ -1629,13 +1790,16 @@
     "microstation"
     "microstrategy"
     "midi"
+    "migadu"
     "mikrotik"
+    "milanote"
     "milvus"
     "minds"
     "minecraft"
     "minetest"
     "mini"
     "minio"
+    "mintlify"
     "minutemailer"
     "miraheze"
     "miro"
@@ -1650,6 +1814,7 @@
     "mobxstatetree"
     "mocha"
     "mockserviceworker"
+    "modal"
     "modin"
     "modrinth"
     "modx"
@@ -1688,6 +1853,7 @@
     "muller"
     "multisim"
     "mumble"
+    "muo"
     "mural"
     "musescore"
     "musicbrainz"
@@ -1698,11 +1864,16 @@
     "myspace"
     "mysql"
     "n26"
+    "n8n"
     "namebase"
     "namecheap"
+    "namemc"
+    "namesilo"
+    "namuwiki"
     "nano"
     "nasa"
     "nationalgrid"
+    "nationalrail"
     "nativescript"
     "natsdotio"
     "naver"
@@ -1714,10 +1885,12 @@
     "nec"
     "neo4j"
     "neovim"
+    "neptune"
     "nestjs"
     "netapp"
     "netbsd"
     "netcup"
+    "netdata"
     "neteasecloudmusic"
     "netflix"
     "netgear"
@@ -1737,13 +1910,14 @@
     "nextdotjs"
     "nextra"
     "nextui"
+    "nexusmods"
     "nfc"
     "nginx"
     "nginxproxymanager"
     "ngrok"
     "ngrx"
     "nhl"
-    "niantic"
+    "nicehash"
     "niconico"
     "nike"
     "nikon"
@@ -1751,7 +1925,6 @@
     "nintendo"
     "nintendo3ds"
     "nintendogamecube"
-    "nintendonetwork"
     "nintendoswitch"
     "nissan"
     "nixos"
@@ -1759,6 +1932,7 @@
     "nodemon"
     "nodered"
     "nokia"
+    "nomad"
     "norco"
     "nordicsemiconductor"
     "nordvpn"
@@ -1774,6 +1948,7 @@
     "npm"
     "nrwl"
     "nsis"
+    "ntfy"
     "nubank"
     "nucleo"
     "nuget"
@@ -1781,9 +1956,11 @@
     "numba"
     "numpy"
     "nunjucks"
+    "nushell"
     "nutanix"
     "nuxtdotjs"
     "nvidia"
+    "nvm"
     "nx"
     "nxp"
     "nzxt"
@@ -1825,7 +2002,9 @@
     "openhab"
     "openid"
     "openjdk"
+    "openjsfoundation"
     "openlayers"
+    "openmediavault"
     "openmined"
     "opennebula"
     "openproject"
@@ -1852,7 +2031,9 @@
     "oppo"
     "opsgenie"
     "opslevel"
+    "optimism"
     "oracle"
+    "orange"
     "orcid"
     "oreilly"
     "org"
@@ -1889,8 +2070,12 @@
     "pandas"
     "pandora"
     "pantheon"
+    "paperlessngx"
     "paperspace"
+    "paperswithcode"
+    "paramountplus"
     "paritysubstrate"
+    "parrotsecurity"
     "parsedotly"
     "passport"
     "pastebin"
@@ -1913,10 +2098,10 @@
     "peloton"
     "penny"
     "penpot"
-    "pepsi"
     "percy"
     "perforce"
     "perl"
+    "perplexity"
     "persistent"
     "personio"
     "petsathome"
@@ -1930,6 +2115,7 @@
     "phosphoricons"
     "photobucket"
     "photocrowd"
+    "photon"
     "photopea"
     "php"
     "phpmyadmin"
@@ -1940,6 +2126,7 @@
     "picartodottv"
     "picnic"
     "picpay"
+    "picrew"
     "picxy"
     "pihole"
     "pimcore"
@@ -1947,6 +2134,7 @@
     "pinescript"
     "pinetwork"
     "pingdom"
+    "pino"
     "pinterest"
     "pioneerdj"
     "piped"
@@ -1955,7 +2143,9 @@
     "piwigo"
     "pix"
     "pixabay"
+    "pixelfed"
     "pixiv"
+    "pixlr"
     "pkgsrc"
     "planet"
     "planetscale"
@@ -1978,6 +2168,7 @@
     "plesk"
     "plex"
     "plotly"
+    "plume"
     "pluralsight"
     "plurk"
     "pluscodes"
@@ -2002,9 +2193,11 @@
     "polywork"
     "pond5"
     "popos"
+    "porkbun"
     "porsche"
     "portainer"
     "portswigger"
+    "posit"
     "postcss"
     "postgresql"
     "posthog"
@@ -2031,10 +2224,13 @@
     "prevention"
     "prezi"
     "prime"
+    "primeng"
+    "primereact"
     "primevideo"
     "printables"
     "prisma"
     "prismic"
+    "privatedivision"
     "privateinternetaccess"
     "probot"
     "processingfoundation"
@@ -2043,6 +2239,7 @@
     "progate"
     "progress"
     "prometheus"
+    "pronounsdotpage"
     "prosieben"
     "proteus"
     "protocolsdotio"
@@ -2068,9 +2265,11 @@
     "purescript"
     "purgecss"
     "purism"
+    "pushbullet"
     "pusher"
     "pwa"
     "pycharm"
+    "pycqa"
     "pydantic"
     "pyg"
     "pypi"
@@ -2085,6 +2284,7 @@
     "qantas"
     "qase"
     "qatarairways"
+    "qbittorrent"
     "qemu"
     "qgis"
     "qi"
@@ -2093,6 +2293,7 @@
     "qiwi"
     "qlik"
     "qmk"
+    "qnap"
     "qt"
     "qualcomm"
     "qualtrics"
@@ -2100,6 +2301,7 @@
     "quantcast"
     "quantconnect"
     "quarkus"
+    "quarto"
     "quasar"
     "qubesos"
     "quest"
@@ -2108,8 +2310,10 @@
     "quicktime"
     "quicktype"
     "quip"
+    "quizlet"
     "quora"
     "qwant"
+    "qwik"
     "qwiklabs"
     "qzone"
     "r"
@@ -2117,6 +2321,7 @@
     "rabbitmq"
     "racket"
     "radar"
+    "radarr"
     "radiopublic"
     "radixui"
     "radstudio"
@@ -2135,8 +2340,11 @@
     "raylib"
     "razer"
     "razorpay"
+    "rclone"
     "react"
+    "reactbootstrap"
     "reacthookform"
+    "reactiveresume"
     "reactivex"
     "reactos"
     "reactquery"
@@ -2150,6 +2358,7 @@
     "reasonstudios"
     "recoil"
     "red"
+    "redash"
     "redbubble"
     "redbull"
     "reddit"
@@ -2166,7 +2375,9 @@
     "relay"
     "relianceindustrieslimited"
     "remark"
+    "remedyentertainment"
     "remix"
+    "removedotbg"
     "renault"
     "render"
     "renovatebot"
@@ -2192,8 +2403,10 @@
     "rewe"
     "rezgo"
     "rhinoceros"
+    "rich"
     "rider"
     "rimacautomobili"
+    "rime"
     "ring"
     "riotgames"
     "ripple"
@@ -2207,13 +2420,17 @@
     "roblox"
     "robloxstudio"
     "robotframework"
+    "rocket"
     "rocketdotchat"
     "rocksdb"
+    "rockstargames"
+    "rockwellautomation"
     "rockylinux"
     "roku"
+    "roll20"
     "rollsroyce"
     "rollupdotjs"
-    "rome"
+    "roon"
     "rootme"
     "roots"
     "rootsbedrock"
@@ -2225,7 +2442,7 @@
     "roundcube"
     "rsocket"
     "rss"
-    "rstudio"
+    "rstudioide"
     "rte"
     "rtl"
     "rtlzwei"
@@ -2233,15 +2450,18 @@
     "rubocop"
     "ruby"
     "rubygems"
+    "rubymine"
     "rubyonrails"
     "rubysinatra"
     "ruff"
+    "rumahweb"
     "rumble"
     "rundeck"
     "runkeeper"
     "runkit"
     "runrundotit"
     "rust"
+    "rustdesk"
     "rxdb"
     "ryanair"
     "rye"
@@ -2253,6 +2473,7 @@
     "sailfishos"
     "sailsdotjs"
     "salesforce"
+    "salla"
     "saltproject"
     "samsclub"
     "samsung"
@@ -2263,16 +2484,19 @@
     "sanity"
     "saopaulometro"
     "sap"
+    "sartorius"
     "sass"
     "sat1"
     "satellite"
     "saturn"
     "saucelabs"
+    "saudia"
     "scala"
     "scaleway"
     "scania"
     "schneiderelectric"
     "scikitlearn"
+    "scilab"
     "scipy"
     "scopus"
     "scpfoundation"
@@ -2330,11 +2554,12 @@
     "shopify"
     "shopware"
     "shortcut"
-    "shotcut"
     "showpad"
     "showtime"
     "showwcase"
     "shutterstock"
+    "sidekiq"
+    "sidequest"
     "siemens"
     "sifive"
     "signal"
@@ -2349,6 +2574,7 @@
     "singlestore"
     "sitecore"
     "sitepoint"
+    "siyuan"
     "skaffold"
     "sketch"
     "sketchfab"
@@ -2356,7 +2582,6 @@
     "skillshare"
     "skoda"
     "sky"
-    "skynet"
     "skypack"
     "skype"
     "skypeforbusiness"
@@ -2377,6 +2602,7 @@
     "snapchat"
     "snapcraft"
     "sncf"
+    "snort"
     "snowflake"
     "snowpack"
     "snyk"
@@ -2385,6 +2611,7 @@
     "socketdotio"
     "softpedia"
     "sogou"
+    "solana"
     "solid"
     "solidity"
     "sololearn"
@@ -2393,6 +2620,7 @@
     "sonarcloud"
     "sonarlint"
     "sonarqube"
+    "sonarr"
     "sonatype"
     "songkick"
     "songoda"
@@ -2408,6 +2636,7 @@
     "sourcetree"
     "southwestairlines"
     "spacemacs"
+    "spaceship"
     "spacex"
     "spacy"
     "sparkar"
@@ -2421,6 +2650,7 @@
     "speedypage"
     "sphinx"
     "spigotmc"
+    "spine"
     "spinnaker"
     "spinrilla"
     "splunk"
@@ -2453,6 +2683,7 @@
     "stackshare"
     "stadia"
     "staffbase"
+    "stagetimer"
     "standardjs"
     "standardresume"
     "starbucks"
@@ -2462,6 +2693,7 @@
     "startrek"
     "starz"
     "statamic"
+    "statista"
     "statuspage"
     "statuspal"
     "steam"
@@ -2473,6 +2705,7 @@
     "steemit"
     "steinberg"
     "stellar"
+    "stencil"
     "stencyl"
     "stimulus"
     "stitcher"
@@ -2503,6 +2736,8 @@
     "subversion"
     "suckless"
     "sumologic"
+    "suno"
+    "sunrise"
     "supabase"
     "supercrease"
     "supermicro"
@@ -2527,6 +2762,7 @@
     "symfony"
     "symphony"
     "sympy"
+    "syncthing"
     "synology"
     "system76"
     "tabelog"
@@ -2537,9 +2773,13 @@
     "taichigraphics"
     "taichilang"
     "tails"
+    "tailscale"
     "tailwindcss"
+    "taipy"
+    "taketwointeractivesoftware"
     "talend"
     "talenthouse"
+    "talos"
     "tamiya"
     "tampermonkey"
     "taobao"
@@ -2551,10 +2791,12 @@
     "tauri"
     "taxbuzz"
     "tcs"
+    "teal"
     "teamcity"
     "teamspeak"
     "teamviewer"
     "ted"
+    "teepublic"
     "teespring"
     "tekton"
     "tele5"
@@ -2579,6 +2821,7 @@
     "tga"
     "thangs"
     "thealgorithms"
+    "theboringcompany"
     "theconversation"
     "thefinals"
     "theirishtimes"
@@ -2593,6 +2836,7 @@
     "thewashingtonpost"
     "thingiverse"
     "thinkpad"
+    "thirdweb"
     "threadless"
     "threads"
     "threedotjs"
@@ -2603,20 +2847,24 @@
     "thurgauerkantonalbank"
     "thymeleaf"
     "ticketmaster"
+    "ticktick"
     "tidal"
     "tiddlywiki"
     "tide"
     "tidyverse"
     "tietoevry"
     "tiktok"
+    "tildapublishing"
     "tile"
     "timescale"
     "tina"
     "tinder"
     "tindie"
     "tinkercad"
+    "tinygrad"
     "tinyletter"
     "tistory"
+    "tldraw"
     "tmobile"
     "tmux"
     "todoist"
@@ -2628,14 +2876,18 @@
     "tomorrowland"
     "ton"
     "topcoder"
+    "topdotgg"
     "toptal"
     "torbrowser"
     "torproject"
     "toshiba"
+    "totvs"
     "tourbox"
+    "tower"
     "toyota"
     "tplink"
     "tqdm"
+    "traccar"
     "tradingview"
     "traefikmesh"
     "traefikproxy"
@@ -2658,10 +2910,12 @@
     "trino"
     "tripadvisor"
     "tripdotcom"
+    "trivago"
     "trivy"
     "trove"
     "trpc"
     "truenas"
+    "trueup"
     "trulia"
     "trustedshops"
     "trustpilot"
@@ -2678,13 +2932,18 @@
     "turkishairlines"
     "turso"
     "tutanota"
+    "tv4play"
     "tvtime"
     "twilio"
+    "twinkly"
+    "twinmotion"
     "twitch"
-    "twitter"
     "typeform"
+    "typeorm"
+    "typer"
     "typescript"
     "typo3"
+    "typst"
     "uber"
     "ubereats"
     "ubiquiti"
@@ -2696,6 +2955,7 @@
     "udemy"
     "ufc"
     "uikit"
+    "uipath"
     "ulule"
     "umami"
     "umbraco"
@@ -2712,13 +2972,14 @@
     "unitednations"
     "unity"
     "unlicense"
-    "uno"
     "unocss"
+    "unpkg"
     "unraid"
     "unrealengine"
     "unsplash"
     "untappd"
     "upcloud"
+    "uphold"
     "uplabs"
     "upptime"
     "ups"
@@ -2741,9 +3002,11 @@
     "vaultwarden"
     "vauxhall"
     "vbulletin"
+    "vectary"
     "vectorlogozone"
     "vectorworks"
     "veeam"
+    "veed"
     "veepee"
     "vega"
     "vegas"
@@ -2761,6 +3024,7 @@
     "viber"
     "viblo"
     "victoriametrics"
+    "victronenergy"
     "vim"
     "vimeo"
     "vimeolivestream"
@@ -2774,13 +3038,16 @@
     "visualstudio"
     "visualstudioappcenter"
     "visualstudiocode"
+    "visx"
     "vite"
+    "vitepress"
     "vitess"
     "vitest"
     "vivaldi"
     "vivawallet"
     "vivino"
     "vivint"
+    "vivo"
     "vk"
     "vlcmediaplayer"
     "vmware"
@@ -2803,6 +3070,7 @@
     "vyond"
     "w3schools"
     "wacom"
+    "wagmi"
     "wagtail"
     "wails"
     "wakatime"
@@ -2817,6 +3085,7 @@
     "wasabi"
     "wasmcloud"
     "wasmer"
+    "watchtower"
     "wattpad"
     "wayland"
     "waze"
@@ -2847,8 +3116,10 @@
     "wellsfargo"
     "wemo"
     "westerndigital"
+    "westernunion"
     "wetransfer"
     "wezterm"
+    "wgpu"
     "whatsapp"
     "wheniwork"
     "wii"
@@ -2857,6 +3128,7 @@
     "wikidotgg"
     "wikidotjs"
     "wikimediacommons"
+    "wikimediafoundation"
     "wikipedia"
     "wikiquote"
     "wikivoyage"
@@ -2879,6 +3151,7 @@
     "wolframlanguage"
     "wolframmathematica"
     "wondershare"
+    "wondersharefilmora"
     "woo"
     "woocommerce"
     "wordpress"
@@ -2890,6 +3163,8 @@
     "writedotas"
     "wwe"
     "wwise"
+    "wykop"
+    "wyze"
     "x"
     "xamarin"
     "xaml"
@@ -2901,6 +3176,7 @@
     "xendit"
     "xero"
     "xfce"
+    "xiaohongshu"
     "xiaomi"
     "xing"
     "xmpp"
@@ -2908,6 +3184,7 @@
     "xrp"
     "xsplit"
     "xstate"
+    "yabai"
     "yale"
     "yamahacorporation"
     "yamahamotorcorporation"
@@ -2928,16 +3205,21 @@
     "youtubetv"
     "yr"
     "yubico"
+    "yunohost"
     "zabka"
+    "zaim"
     "zalando"
     "zalo"
+    "zap"
     "zapier"
     "zara"
     "zazzle"
     "zcash"
+    "zcool"
     "zdf"
     "zebpay"
     "zebratechnologies"
+    "zedindustries"
     "zelle"
     "zend"
     "zendesk"
@@ -2950,6 +3232,7 @@
     "zhihu"
     "zig"
     "zigbee"
+    "zigbee2mqtt"
     "ziggo"
     "zilch"
     "zillow"
