@@ -1,6 +1,6 @@
 ;;; tex-bar.el --- toolbar icons on AUCTeX in GNU emacs.  -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2004-2021  Free Software Foundation, Inc.
+;; Copyright (C) 2004-2022  Free Software Foundation, Inc.
 
 ;; This program is free software; you can redistribute it and/or
 ;; modify it under the terms of the GNU General Public License as
@@ -18,6 +18,7 @@
 ;; MA 02110-1301 USA
 
 ;; Author: Miguel V. S. Frasson <frasson@math.leidenuniv.nl>
+;; Maintainer: auctex-devel@gnu.org
 ;; Keywords: tool-bar, tex, latex
 
 ;;; Commentary:
@@ -62,8 +63,7 @@
 
 (require 'toolbar-x)
 
-;; for error handling
-(require 'tex-buf)
+(require 'tex)
 
 ;; For the symbol toolbar
 (require 'latex)
@@ -84,7 +84,7 @@ If there is no help, the empty string is returned."
 (defcustom TeX-bar-TeX-buttons
   '(new-file open-file dired kill-buffer save-buffer cut copy paste undo
              separator tex next-error view bibtex spell)
-  "List of buttons available in `tex-mode'.
+  "List of buttons available in `plain-TeX-mode'.
 It should be a list in the same format of the BUTTONS parameter
 in function `toolbarx-install-toolbar', often a symbol that
 labels a button.
@@ -134,43 +134,43 @@ the argument BUTTON-ALIST in function `toolbarx-install-toolbar'."
   :group 'TeX-tool-bar-button-definitions)
 
 (defcustom TeX-bar-TeX-button-alist
-  '((tex :image (lambda nil (if TeX-PDF-mode "pdftex" "tex"))
+  `((tex :image ,(lambda nil (if TeX-PDF-mode "pdftex" "tex"))
          :command (progn
                     (TeX-save-document #'TeX-master-file)
                     (TeX-command "TeX" #'TeX-master-file -1))
-         :help (lambda (&rest ignored)
-                 (TeX-bar-help-from-command-list "TeX")))
+         :help ,(lambda (&rest _ignored)
+                  (TeX-bar-help-from-command-list "TeX")))
     (pdftex :image "pdftex"
             :command (progn
                        (TeX-save-document #'TeX-master-file)
                        (TeX-command "PDFTeX" #'TeX-master-file -1))
-            :help (lambda (&rest ignored)
-                    (TeX-bar-help-from-command-list "PDFTeX")))
+            :help ,(lambda (&rest _ignored)
+                     (TeX-bar-help-from-command-list "PDFTeX")))
     (next-error :image "error"
                 :command TeX-next-error
                 :enable (TeX-error-report-has-errors-p)
                 :visible (TeX-error-report-has-errors-p))
-    (view :image (lambda nil (if TeX-PDF-mode "viewpdf" "viewdvi"))
+    (view :image ,(lambda nil (if TeX-PDF-mode "viewpdf" "viewdvi"))
           :command (TeX-command "View" #'TeX-master-file -1)
-          :help (lambda (&rest ignored)
-                  (TeX-bar-help-from-command-list "View")))
+          :help ,(lambda (&rest _ignored)
+                   (TeX-bar-help-from-command-list "View")))
     (file :image "dvips"
           :command (TeX-command "File" #'TeX-master-file -1)
           :visible (not TeX-PDF-mode)
-          :help (lambda (&rest ignored)
-                  (TeX-bar-help-from-command-list "File")))
+          :help ,(lambda (&rest _ignored)
+                   (TeX-bar-help-from-command-list "File")))
     (bibtex :image "bibtex"
             :command (TeX-command "BibTeX" #'TeX-master-file -1)
-            :help (lambda (&rest ignored)
-                    (TeX-bar-help-from-command-list "BibTeX")))
+            :help ,(lambda (&rest _ignored)
+                     (TeX-bar-help-from-command-list "BibTeX")))
     (clean  :image "delete"
             :command (TeX-command "Clean" #'TeX-master-file -1)
-            :help (lambda (&rest ignored)
-                    (TeX-bar-help-from-command-list "Clean")))
+            :help ,(lambda (&rest _ignored)
+                     (TeX-bar-help-from-command-list "Clean")))
     (spell  :image "spell"
             :command (TeX-command "Spell" #'TeX-master-file -1)
-            :help (lambda (&rest ignored)
-                    (TeX-bar-help-from-command-list "Spell"))))
+            :help ,(lambda (&rest _ignored)
+                     (TeX-bar-help-from-command-list "Spell"))))
   ;; latex-symbols-experimental?
   "Alist for button definitions in TeX bar.
 Value should le a list where each element is of format (KEY .
@@ -203,7 +203,7 @@ format of the argument MEANING-ALIST in the mentioned function."
         (insert (format "\n\n`%s' provides the following buttons:\n  " (car i)))
         (dolist (j (cdr i))
           (insert (format " %s" j)))
-        (fill-region (point-at-bol) (point-at-eol))))
+        (fill-region (line-beginning-position) (line-end-position))))
     (display-buffer "*TeX tool bar buttons*" t)))
 
 ;;; Installation of the tool bar
@@ -211,7 +211,6 @@ format of the argument MEANING-ALIST in the mentioned function."
 (defun TeX-install-toolbar ()
   "Install toolbar buttons for TeX mode."
   (interactive)
-  (require 'toolbar-x)
   (add-to-list 'toolbarx-image-path
                (expand-file-name "images" TeX-data-directory))
   (add-hook 'TeX-PDF-mode-hook #'toolbarx-refresh nil t)
@@ -225,7 +224,7 @@ format of the argument MEANING-ALIST in the mentioned function."
 (defcustom TeX-bar-LaTeX-buttons
   '(new-file open-file dired kill-buffer save-buffer cut copy paste undo
              separator latex next-error view bibtex spell)
-  "List of buttons available in `latex-mode'.
+  "List of buttons available in `LaTeX-mode'.
 It should be a list in the same format of the BUTTONS parameter
 in function `toolbarx-install-toolbar', often a symbol that
 labels a button.
@@ -261,10 +260,6 @@ alists, see variable `TeX-bar-LaTeX-all-button-alists'."
                                (sexp :tag "General element"))))
   :group 'TeX-tool-bar)
 
-(defgroup TeX-tool-bar-button-definitions nil
-  "Collections of button definitions."
-  :group 'TeX-tool-bar)
-
 (defcustom TeX-bar-LaTeX-all-button-alists
   '(TeX-bar-LaTeX-button-alist
     toolbarx-default-toolbar-meaning-alist)
@@ -275,45 +270,45 @@ the argument BUTTON-ALIST in function `toolbarx-install-toolbar'."
   :group 'TeX-tool-bar-button-definitions)
 
 (defcustom TeX-bar-LaTeX-button-alist
-  '((latex :image (lambda nil (if TeX-PDF-mode "pdftex" "tex"))
+  `((latex :image ,(lambda nil (if TeX-PDF-mode "pdftex" "tex"))
            :command (progn
                       (TeX-save-document #'TeX-master-file)
                       (TeX-command "LaTeX" #'TeX-master-file -1))
-           :help (lambda (&rest ignored)
-                   (TeX-bar-help-from-command-list "LaTeX")))
+           :help ,(lambda (&rest _ignored)
+                    (TeX-bar-help-from-command-list "LaTeX")))
     (pdflatex :image "pdftex"
               :command (progn
                          (TeX-save-document #'TeX-master-file)
                          (TeX-command "PDFLaTeX" #'TeX-master-file -1))
-              :help (lambda (&rest ignored)
-                      (TeX-bar-help-from-command-list "PDFLaTeX")))
+              :help ,(lambda (&rest _ignored)
+                       (TeX-bar-help-from-command-list "PDFLaTeX")))
     (next-error :image "error"
                 :command TeX-next-error
                 :enable (TeX-error-report-has-errors-p)
                 :visible (TeX-error-report-has-errors-p))
-    (view :image (lambda nil (if TeX-PDF-mode "viewpdf" "viewdvi"))
+    (view :image ,(lambda nil (if TeX-PDF-mode "viewpdf" "viewdvi"))
           :command (TeX-command "View" #'TeX-master-file -1)
-          :help (lambda (&rest ignored)
-                  (TeX-bar-help-from-command-list "View")))
+          :help ,(lambda (&rest _ignored)
+                   (TeX-bar-help-from-command-list "View")))
     (file :image "dvips"
           :command (TeX-command "File" #'TeX-master-file -1)
           :visible (not TeX-PDF-mode)
-          :help (lambda (&rest ignored)
-                  (TeX-bar-help-from-command-list "File")))
+          :help ,(lambda (&rest _ignored)
+                   (TeX-bar-help-from-command-list "File")))
     (bibtex :image "bibtex"
             :command (TeX-command (if LaTeX-using-Biber "Biber" "BibTeX")
                                   #'TeX-master-file -1)
-            :help (lambda (&rest ignored)
-                    (TeX-bar-help-from-command-list
-                     (if LaTeX-using-Biber "Biber" "BibTeX"))))
+            :help ,(lambda (&rest _ignored)
+                     (TeX-bar-help-from-command-list
+                      (if LaTeX-using-Biber "Biber" "BibTeX"))))
     (clean  :image "delete"
             :command (TeX-command "Clean" #'TeX-master-file -1)
-            :help (lambda (&rest ignored)
-                    (TeX-bar-help-from-command-list "Clean")))
+            :help ,(lambda (&rest _ignored)
+                     (TeX-bar-help-from-command-list "Clean")))
     (spell  :image "spell"
             :command (TeX-command "Spell" #'TeX-master-file -1)
-            :help (lambda (&rest ignored)
-                    (TeX-bar-help-from-command-list "Spell")))
+            :help ,(lambda (&rest _ignored)
+                     (TeX-bar-help-from-command-list "Spell")))
     (latex-symbols-experimental . (:alias :eval-group
                                           LaTeX-symbols-toolbar-switch-contents
                                           LaTeX-symbols-toolbar-contents)))
@@ -348,7 +343,7 @@ format of the argument MEANING-ALIST in the mentioned function."
         (insert (format "\n\n`%s' provides the following buttons:\n  " (car i)))
         (dolist (j (cdr i))
           (insert (format " %s" j)))
-        (fill-region (point-at-bol) (point-at-eol))))
+        (fill-region (line-beginning-position) (line-end-position))))
     (display-buffer "*TeX tool bar buttons*" t)))
 
 ;;; Installation of the tool bar
@@ -356,7 +351,6 @@ format of the argument MEANING-ALIST in the mentioned function."
 (defun LaTeX-install-toolbar ()
   "Install toolbar buttons for LaTeX mode."
   (interactive)
-  (require 'toolbar-x)
   (add-to-list 'toolbarx-image-path
                (expand-file-name "images" TeX-data-directory))
   (add-hook 'TeX-PDF-mode-hook #'toolbarx-refresh nil t)
@@ -461,32 +455,35 @@ format of the argument MEANING-ALIST in the mentioned function."
                               (cons (cons menu-str (list menu-buttons))
                                     menu-strings-alist-temp)))))))))))
        (list-strings (let* ((list-str-temp))
-                       (dolist (i menu-strings-buttons-alist
-                                  (nreverse list-str-temp))
+                       (dolist (i menu-strings-buttons-alist)
                          (setq list-str-temp (cons (car i)
-                                                   list-str-temp))))))
+                                                   list-str-temp)))
+                       (nreverse list-str-temp))))
+  ;; Will be defined by running LaTeX-install-toolbar.
+  (defvar LaTeX-symbols-active-menuitem)
   (defvar LaTeX-symbols-toolbar-visible-flag nil
     "Non-nil means that the LaTeX symbols on toolbar are visible.
 Internal variable.")
   (defconst LaTeX-symbols-toolbar-switch-contents
     `(;; the on-off switch button
       (latex-symbols-switch
-       :image (lambda nil (if LaTeX-symbols-toolbar-visible-flag
-                              "ltx-symb-turn-off"
-                            "ltx-symb-turn-on"))
+       :image ,(lambda ()
+                 (if LaTeX-symbols-toolbar-visible-flag
+                     "ltx-symb-turn-off"
+                   "ltx-symb-turn-on"))
        :command (progn
                   (setq LaTeX-symbols-toolbar-visible-flag
                         (not LaTeX-symbols-toolbar-visible-flag))
                   (toolbarx-refresh))
        ;; help message depends on if symb-toolbar is on or off, and in
        ;; the name of the current class of symbols
-       :help (lambda (&rest ignore)
-               (concat "Turn "
-                       (if LaTeX-symbols-toolbar-visible-flag "off " "on ")
-                       "the toolbar of LaTeX symbols (current class: "
-                       (nth (1- LaTeX-symbols-active-menuitem)
-                            (quote ,list-strings))
-                       ")")))
+       :help ,(lambda (&rest _ignore)
+                (concat "Turn "
+                        (if LaTeX-symbols-toolbar-visible-flag "off " "on ")
+                        "the toolbar of LaTeX symbols (current class: "
+                        (nth (1- LaTeX-symbols-active-menuitem)
+                             list-strings)
+                        ")")))
       ;; the dropdown button, that also switch on the symbols
       ,(append '(:dropdown-group)
                list-strings
