@@ -1,9 +1,10 @@
 ;;; tex-style.el --- Customizable variables for AUCTeX style files  -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2005-2023  Free Software Foundation, Inc.
+;; Copyright (C) 2005-2024  Free Software Foundation, Inc.
 
 ;; Author: Reiner Steib <Reiner.Steib@gmx.de>
-;; Keywords: tex, wp, convenience
+;; Maintainer: auctex-devel@gnu.org
+;; Keywords: tex, text, convenience
 
 ;; This file is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -218,12 +219,11 @@ It can be a list of themes or a function.  If it is the symbol
 
 ;; style/biblatex.el
 
-(defvar LaTeX-biblatex-use-Biber t
+(defvar-local LaTeX-biblatex-use-Biber t
   "Whether to use Biber with biblatex.
 
 This variable is intended to be used as a file local variable to
 override the autodetection of the biblatex backend.")
-(make-variable-buffer-local 'LaTeX-biblatex-use-Biber)
 (put 'LaTeX-biblatex-use-Biber 'safe-local-variable #'booleanp)
 
 ;; style/catchfilebetweentags.el
@@ -304,8 +304,8 @@ becomes the default value meaning that verbatim fontification is
 always performed for the characters in the list, no matter if
 your document actually defines shortverb chars using
 \\DefineShortVerb."
-  :type '(repeat character))
-(put 'LaTeX-fancyvrb-chars 'safe-local-variable #'listp)
+  :type '(repeat character)
+  :safe #'listp)
 
 ;; style/fontspec.el
 
@@ -421,8 +421,8 @@ becomes the default value meaning that verbatim fontification is
 always performed for the characters in the list, no matter if
 your document actually defines shortvrb chars using
 \\MakeShortVrb."
-  :type '(repeat character))
-(put 'LaTeX-shortvrb-chars 'safe-local-variable #'listp)
+  :type '(repeat character)
+  :safe #'listp)
 
 ;; style/splitidx.el
 
