@@ -1,6 +1,6 @@
 ;;; toolbar-x.el --- fancy toolbar handling in Emacs  -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2004-2021  Free Software Foundation, Inc.
+;; Copyright (C) 2004-2022  Free Software Foundation, Inc.
 
 ;; This program is free software; you can redistribute it and/or
 ;; modify it under the terms of the GNU General Public License as
@@ -17,7 +17,8 @@
 ;; Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 ;; MA 02110-1301 USA
 
-;;; Author: Miguel Vinicius Santini Frasson
+;; Author: Miguel Vinicius Santini Frasson <frasson@math.leidenuniv.nl>
+;; Maintainer: auctex-devel@gnu.org
 
 ;;; Commentary:
 ;; This program implements a common interface to display toolbar
@@ -912,7 +913,7 @@ in the end of SWITCHES, which is returned."
             (setq only-symbols-flag (and only-symbols-flag (symbolp i)))))
         (let ((count 0))
           (dolist (i dropdown-list)
-            ;; list-strings and list-buttons are buildt reversed
+            ;; list-strings and list-buttons are built reversed
             (setq list-strings (cons (toolbarx-make-string-from-symbol i)
                                      list-strings))
             (setq count (1+ count))
@@ -925,9 +926,9 @@ in the end of SWITCHES, which is returned."
       ;; if not, the it must start with string
       (unless (stringp (car dropdown-list))
         (error "%s %s %s"
-               "If not all itens on dropdown are symbols, then a string"
+               "If not all items on dropdown are symbols, then a string"
                "must come before each set of buttons; no string found"
-               "in first position."))
+               "in first position"))
       (let ((count 0)
             (elem)
             (temp-list-buttons))
@@ -1432,8 +1433,7 @@ line of buttons.  The only property supported for this button is
     (if global-flag
         (setq-default toolbarx-internal-button-switches
                       switches)
-      (set (make-local-variable 'toolbarx-internal-button-switches)
-           switches)
+      (setq-local toolbarx-internal-button-switches switches)
       (make-local-variable 'tool-bar-map)))
   (toolbarx-refresh global-flag))
 
@@ -1462,11 +1462,11 @@ line of buttons.  The only property supported for this button is
                  :command save-buffer
                  :enable (and
                            (buffer-modified-p)
-                           (buffer-file-name)
+                           (buffer-file-name (buffer-base-buffer))
                            (not (window-minibuffer-p
                                  (frame-selected-window menu-updating-frame))))
                  :help "Save current buffer to its file"
-                 :visible (or buffer-file-name
+                 :visible (or (buffer-file-name (buffer-base-buffer))
                               (not (eq 'special
                                        (get major-mode 'mode-class)))))
 
@@ -1476,7 +1476,7 @@ line of buttons.  The only property supported for this button is
                          (window-minibuffer-p
                           (frame-selected-window menu-updating-frame)))
                 :help "Write current buffer to another file"
-                :visible (or buffer-file-name
+                :visible (or (buffer-file-name (buffer-base-buffer))
                              (not (eq 'special (get major-mode 'mode-class)))))
 
     (undo :image "undo"
@@ -1553,7 +1553,7 @@ To reproduce the default toolbar with use as BUTTON
 in `toolbarx-install-toolbar':
 
 \(toolbarx-install-toolbar
- '((open-file dired kill-buffer save-buffer write-file undo cut
+ \\='((open-file dired kill-buffer save-buffer write-file undo cut
                copy paste search-forward print-buffer customize help))
  toolbarx-default-toolbar-meaning-alist)
 
